﻿#pragma once

#include "Enums/RRDADSEnums.h"
#include "Math/Transform.h"
#include "Resources/FGItemDescriptor.h"
#include "RRDADSStructs.generated.h"


USTRUCT(BlueprintType)
struct REFINEDRDAPI_API FRRDADSAdapterCoverDetails
{
	GENERATED_BODY()

public:
	/* The relative transform from the buildings origin */
	UPROPERTY(EditDefaultsOnly, BlueprintReadWrite)
	FTransform mRelativeTransform;

	/* If the cover should be a conveyor cover or a pipe cover */
	UPROPERTY(EditDefaultsOnly, BlueprintReadWrite)
	bool bIsConveyor = true;
};


USTRUCT(BlueprintType)
struct REFINEDRDAPI_API FRRDADSModAdapterInventorySlotAccess
{
	GENERATED_BODY()

public:
	/* The Inventory Slot Index */
	UPROPERTY(EditDefaultsOnly, BlueprintReadOnly)
	int mInventorySlotIndex = 0;

	/* A custom display name for the inventory slot that will be displayed in the digital storage UI.
	   This makes it easier for players to understand what this slot is used for.
	 */
	UPROPERTY(EditDefaultsOnly, BlueprintReadOnly)
	FText mInventorySlotDisplayName;

	/* Set how digital storage should interact with this inventory slot */
	UPROPERTY(EditDefaultsOnly, BlueprintReadOnly)
	ERRDADSInventorySlotAccessInteraction mInteraction = ERRDADSInventorySlotAccessInteraction::Ignore;

	/* Select the item resource form that will be displayed in the digital storage UI
	   This will only display items of this form when players search for an item.
	 */
	UPROPERTY(EditDefaultsOnly, BlueprintReadOnly)
	EResourceForm mSlotItemForm = EResourceForm::RF_SOLID;

	UPROPERTY(BlueprintReadOnly, meta=(NoAutoJson = true))
	bool mOverrideItemFilter = false;

	/* Limit the list of items this slot should contain, only items in this list will be displayed on the digital storage UI */
	UPROPERTY(EditDefaultsOnly, BlueprintReadOnly, meta=(EditCondition = mOverrideItemFilter))
	TArray<TSubclassOf<UFGItemDescriptor>> mItemFilter;

	/* Should check if the inventory slot has an Item Filter set
	 This will override the item class that the player selects with the allowed item class on the slot.
	 Also disables item selection in the UI.
	 */
	UPROPERTY(EditDefaultsOnly, BlueprintReadOnly)
	bool mCheckSlotItemFilter = false;
};

USTRUCT(BlueprintType)
struct REFINEDRDAPI_API FRRDADSModAdapterInventoryAccess
{
	GENERATED_BODY()

public:
	/* A custom name that should be used in the digital storage UI, by default will use "Inventory 1" */
	UPROPERTY(EditDefaultsOnly, BlueprintReadOnly)
	FText mInventoryDisplayName;

	/* The Inventory Name to search for */
	UPROPERTY(EditDefaultsOnly, BlueprintReadOnly)
	FName mInventoryName;

	/* The Inventory index to search for in case couldn't find by name */
	UPROPERTY(EditDefaultsOnly, BlueprintReadOnly)
	int mInventoryIndex = 0;

	/* The Inventory slots to allow access to Digital Storage */
	UPROPERTY(EditDefaultsOnly, BlueprintReadOnly)
	TArray<FRRDADSModAdapterInventorySlotAccess> mInventorySlots;
};
